#
# spec file for package opus
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname      0
Name:           opus
Version:        1.1.3
Release:        2.1
Summary:        Opus Audio Codec Library
License:        BSD-3-Clause
Group:          System/Libraries
Url:            http://opus-codec.org/
Source:         http://downloads.xiph.org/releases/opus/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Opus codec is designed for interactive speech and audio transmission over
the Internet. It is designed by the IETF Codec Working Group and incorporates
technology from Skype's SILK codec and Xiph.Org's CELT codec.

%package -n libopus%{soname}
Summary:        Opus Audio Codec Library
Group:          System/Libraries

%description -n libopus%{soname}
The Opus codec is designed for interactive speech and audio transmission over
the Internet. It is designed by the IETF Codec Working Group and incorporates
technology from Skype's SILK codec and Xiph.Org's CELT codec.

%package -n libopus-devel
Summary:        Opus Audio Codec Library Development Environment
Group:          Development/Libraries/C and C++
Requires:       libopus%{soname} = %{version}

%description -n libopus-devel
The Opus codec is designed for interactive speech and audio transmission over
the Internet. It is designed by the IETF Codec Working Group and incorporates
technology from Skype's SILK codec and Xiph.Org's CELT codec.

%package -n libopus-devel-static
Summary:        Opus Audio Codec Library Static Library
Group:          Development/Libraries/C and C++
Requires:       libopus-devel = %{version}

%description -n libopus-devel-static
The Opus codec is designed for interactive speech and audio transmission over
the Internet. It is designed by the IETF Codec Working Group and incorporates
technology from Skype's SILK codec and Xiph.Org's CELT codec.

%prep
%setup -q

%build
%configure \
%if 0%{?suse_version} <= 1110
  --disable-intrinsics \
%endif
  --disable-silent-rules \
  --disable-doc \
  --enable-custom-modes

make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

find %{buildroot} -type f -name "*.la" -delete -print

%post   -n libopus%{soname} -p /sbin/ldconfig

%postun -n libopus%{soname} -p /sbin/ldconfig

%files -n libopus%{soname}
%defattr(-,root,root)
%doc AUTHORS COPYING README
%{_libdir}/libopus.so.%{soname}
%{_libdir}/libopus.so.%{soname}.*

%files -n libopus-devel
%defattr(-,root,root)
%{_libdir}/libopus.so
%{_includedir}/opus
%{_libdir}/pkgconfig/opus.pc
%{_datadir}/aclocal/opus.m4

%files -n libopus-devel-static
%defattr(-,root,root)
%{_libdir}/libopus.a

%changelog
* Sat Aug 13 2016 zaitor@opensuse.org
- Update to version 1.1.3:
  + Neon optimizations improving performance on ARMv7 and ARMv8 by
    up to 15%%.
  + Fixes some issues with 16-bit platforms (e.g. TI C55x).
  + Fixes to comfort noise generation (CNG).
  + Documenting that PLC packets can also be 2 bytes.
  + Includes experimental ambisonics work (--enable-ambisonics).
- Stop passing conditional --enable/disable-intrinsics, it's
  enabled by default now.
- Not adding the new --enable-ambisonics to configure, it's still
  experimental.
* Wed Jan 27 2016 olaf@aepfle.de
- Disable SSE2 in SLE_11 due to code or compiler bugs.
* Tue Jan 26 2016 mpluskal@suse.com
- Enable tests during package build
- Cleanup spec file with spec-cleaner
- Drop not needed libtool dependency for build
* Tue Jan 19 2016 idonmez@suse.com
- Update to version 1.1.2, fixes the following bugs:
  + Resetting the encoder or decoder state with OPUS_RESET_STATE
    would disable some run-time selected architecture-specific
    optimizations.
  + In hybrid mode discontinuous transmission (DTX) operation,
    the comfort noise above 8 kHz was incorrectly estimated
    and could oscillate in time.
* Wed Dec  2 2015 zaitor@opensuse.org
- Update to version 1.1.1:
  + x86 SSE, SSE2 and SSE4.1 intrinsics optimizations with run-time
    CPU detection.
  + MIPS intrinsics optimizations.
  + ARM Neon optimizations.
  + Many architecture-independent optimizations and memory
    footprint reductions that should improve performance on all
    platforms, and several minor bug fixes.
- Pass --enable-intrinsics to configure.
* Sun Dec  8 2013 zaitor@opensuse.org
- Update to version 1.1:
  + New analysis code and tuning that significantly improves
    encoding quality, especially for variable-bitrate (VBR).
  + Automatic detection of speech or music to decide which encoding
    mode to use.
  + Surround with good quality at 128 kbps for 5.1 and usable down
    to 48 kbps.
  + Speed improvements on all architectures, especially ARM, where
    decoding uses around 40%% less CPU and encoding uses around 30%%
    less CPU.
* Thu Aug  1 2013 zaitor@opensuse.org
- Update to version 1.0.3:
  + Backport of the new 1.1 surround API.
  + Fixes for a few minor glitches during mode switching.
  + Some minor fixed-point fixes.
  + Fix a regression in the FEC code introduced in 1.0.2.
* Sat Feb  2 2013 zaitor@opensuse.org
- Update to version 1.0.2:
  + Fix an out-of-bounds read security issue.
  + Fixes and improvements to the PLC and hybrid mode quality.
- Drop
  opus-fix-out-of-bounds-read-issue-with-the-padding-handling.patch
  Fixed upstream.
* Sun Jan 13 2013 zaitor@opensuse.org
- Add
  opus-fix-out-of-bounds-read-issue-with-the-padding-handling.patch
  Fixes an out-of-bounds read that could be triggered by a
   malicious Opus packet causing an integer wrap-around in the
   padding code.
* Wed Sep 19 2012 zaitor@opensuse.org
- Update to version 1.0.1:
  + First bugfix release of stable version.
  + Changes are mostly buildfixes.
  + Fully compliant with the Opus specification.
- Remove unneeded autoconf, automake, gcc glibc-devel and make.
- Remove manual deletion of docs, instead pass --disable-doc to
  configure.
- Minor spec cleanup.
* Thu May 31 2012 pascal.bleser@opensuse.org
- initial version (0.9.14)
